@@ -38,6 +38,10 @@ static VALUE cgsl_eigen_nonsymm_workspace;
 static VALUE cgsl_eigen_nonsymmv_workspace;
 #endif
 
+#ifdef HAVE_EIGEN_GEN
+static VALUE cgensymm, mgensymm;
+#endif
+
 static VALUE rb_gsl_eigen_symm_alloc(VALUE klass, VALUE nn)
 {
   gsl_eigen_symm_workspace *w = NULL;
@@ -1256,6 +1260,96 @@ static VALUE rb_gsl_eigen_nonsymmv_sort(int argc, VALUE *argv, VALUE obj)
 
 #endif
 
+#ifdef HAVE_EIGEN_GEN
+
+static VALUE rb_gsl_eigen_gensymm_alloc(VALUE klass, VALUE nn)
+{
+  gsl_eigen_gen_workspace *w = NULL;
+  CHECK_FIXNUM(nn);
+  w = gsl_eigen_gen_alloc(FIX2INT(nn));
+  return Data_Wrap_Struct(cgensymm, 0, gsl_eigen_gen_free, w);
+}
+
+static int check_argv_gensymm(int argc, VALUE *argv, VALUE obj, gsl_matrix **A, gsl_matrix **B,
+	gsl_vector **eval, gsl_eigen_gensymm_workspace **w);
+static VALUE rb_gsl_eigen_gensymm(int argc, VALUE *argv, VALUE obj)
+{
+	gsl_matrix *A = NULL, *B = NULL;
+	gsl_vector *eval = NULL;
+	gsl_eigen_gensymm_workspace *w = NULL;
+	int flag;
+	VALUE veval;
+	flag = check_argv_gensymm(argc, argv, obj, &A, &B, &eval, &w);
+
+//	gsl_eigen_gensymm(A, B, eval, w);
+
+	switch (flag) {
+	case 0:
+		veval = argv[2];
+		break;
+	case 1:
+		veval = Data_Wrap_Struct(cgsl_eigen_values, 0, gsl_vector_free, eval);
+		break;
+	case 2:
+		veval = argv[2];
+		gsl_eigen_gensymm_free(w);
+		break;
+	case 3:
+		veval = Data_Wrap_Struct(cgsl_eigen_values, 0, gsl_vector_free, eval);
+		gsl_eigen_gensymm_free(w);
+		break;
+	}
+
+	return veval;
+}
+
+static int check_argv_gensymm(int argc, VALUE *argv, VALUE obj, gsl_matrix **A, gsl_matrix **B,
+	gsl_vector **eval, gsl_eigen_gensymm_workspace **w)
+{
+	int argc2 = argc;
+	int flag = 0;
+	if (CLASS_OF(obj) == cgensymm) {
+		Data_Get_Struct(obj, gsl_eigen_gensymm_workspace, *w);
+	} else {
+		if (rb_obj_is_kind_of(argv[argc-1], cgensymm)) {
+			Data_Get_Struct(argv[argc-1], gsl_eigen_gensymm_workspace, *w);
+			argc2 = argc-1;
+		} else {
+			/* workspace is not given */
+		}
+	}
+	switch (argc2) {
+	case 2:
+		CHECK_MATRIX(argv[0]); CHECK_MATRIX(argv[1]);
+		Data_Get_Struct(argv[0], gsl_matrix, *A);
+		Data_Get_Struct(argv[1], gsl_matrix, *B);
+		break;
+	case 3:
+		if (rb_obj_is_kind_of(argv[2], cgensymm)) {
+			Data_Get_Struct(argv[2], gsl_eigen_gensymm_workspace, *w);
+		} else {
+			CHECK_VECTOR(argv[2]);
+			Data_Get_Struct(argv[2], gsl_vector, *eval);
+		}
+		CHECK_MATRIX(argv[0]); CHECK_MATRIX(argv[1]);
+		Data_Get_Struct(argv[0], gsl_matrix, *A);
+		Data_Get_Struct(argv[1], gsl_matrix, *B);
+		break;
+	default:
+		rb_raise(rb_eArgError, "wrong number of arguments (%d for 2 or 3)", argc);
+	}
+	if (*eval == NULL) {
+		*eval = gsl_vector_alloc((*A)->size1);
+		flag += 1;
+	}
+	if (*w == NULL) {
+		*w = gsl_eigen_gensymm_alloc((*A)->size1);
+		flag += 2;
+	}
+	return flag;
+}
+		
+#endif
 
 void Init_gsl_eigen(VALUE module)
 {
@@ -1403,5 +1497,16 @@ void Init_gsl_eigen(VALUE module)
 			     rb_gsl_eigen_nonsymmv_sort, -1);
 #endif
 
+#ifdef HAVE_EIGEN_GEN
+	mgensymm = rb_define_module_under(mgsl_eigen, "Gensymm");
+	cgensymm = rb_define_class_under(mgensymm, "Workspace", cGSL_Object);
+	rb_define_singleton_method(mgensymm, "alloc", rb_gsl_eigen_gensymm_alloc, 1);
+	
+	rb_define_method(cgensymm, "gensymm", rb_gsl_eigen_gensymm, -1);
+	rb_define_module_function(module, "eigen_gensymm", rb_gsl_eigen_gensymm, -1);
+	rb_define_module_function(mgsl_eigen, "gensymm", rb_gsl_eigen_gensymm, -1);	
+	rb_define_module_function(mgensymm, "gensymm", rb_gsl_eigen_gensymm, -1);		
+#endif
+
 }
 
