@@ -135,6 +135,14 @@ begin
     RB_GSL_CONFIG.printf("#ifndef HAVE_EIGEN_FRANCIS\n#define HAVE_EIGEN_FRANCIS\n#endif\n")
   end
 
+  if have_library("gsl", "gsl_eigen_gen_alloc")
+    RB_GSL_CONFIG.printf("#ifndef HAVE_EIGEN_GEN\n#define HAVE_EIGEN_GEN\n#endif\n")
+  end
+
+  if have_library("gsl", "gsl_stats_correlation")
+    RB_GSL_CONFIG.printf("#ifndef HAVE_GSL_STATS_CORRELATION\n#define HAVE_GSL_STATS_CORRELATION\n#endif\n")
+  end
+  
   begin
     print("checking rb-gsl version...")
     IO.popen("cat ../VERSION") do |f|
@@ -210,116 +218,8 @@ File.open("../lib/rbgsl.rb", "w") do |file|
   file.print("require\(\"gsl/oper.rb\"\)\n")
 end
 
-srcs = %w(
-array 
-array_complex 
-blas 
-blas1 
-blas2 
-blas3 
-block
-bspline
-cdf 
-cheb 
-combination 
-common 
-complex 
-const 
-const_additional
-cqp
-deriv
-dirac
-dht 
-diff 
-eigen 
-error 
-fcmp 
-fft 
-fit 
-fresnel
-function 
-graph 
-gsl 
-gsl_narray 
-histogram 
-histogram_oper
-histogram2d 
-histogram_find
-histogram3d_source
-histogram3d
-ieee 
-integration 
-interp 
-jacobi
-linalg 
-linalg_complex 
-math 
-matrix 
-matrix_complex 
-matrix_double 
-matrix_int 
-min 
-monte 
-multifit 
-multimin
-multimin_fsdf
-multiroots 
-ntuple 
-odeiv 
-ool
-oper_complex_source 
-permutation 
-poly 
-poly2 
-qrng 
-randist 
-rational 
-rng 
-root 
-sf 
-sf_airy 
-sf_bessel 
-sf_clausen 
-sf_coulomb 
-sf_coupling 
-sf_dawson 
-sf_debye 
-sf_dilog 
-sf_elementary 
-sf_ellint 
-sf_elljac 
-sf_erfc 
-sf_exp 
-sf_expint 
-sf_fermi_dirac 
-sf_gamma 
-sf_gegenbauer 
-sf_hyperg 
-sf_laguerre 
-sf_lambert 
-sf_legendre 
-sf_log
-sf_mathieu
-sf_power 
-sf_psi 
-sf_synchrotron 
-sf_transport 
-sf_trigonometric 
-sf_zeta 
-siman 
-sort 
-spline 
-stats 
-sum 
-tamu_anova
-tensor
-vector 
-vector_complex 
-vector_double 
-vector_int 
-wavelet 
-)
+srcs = Dir.glob("*.c") - ["vector_source.c", "matrix_source.c", "tensor_source.c", "poly_source.c", "block_source.c"]
 
-$objs = srcs.collect{|i| i+".o"}
+$objs = srcs.collect { |f| f.sub(".c", ".o") }
 
 create_makefile("rb_gsl")
