@@ -1,7 +1,7 @@
 /*
   matrix_complex.c
   Ruby/GSL: Ruby extension library for GSL (GNU Scientific Library)
-    (C) Copyright 2001-2004 by Yoshiki Tsunesada
+    (C) Copyright 2001-2006 by Yoshiki Tsunesada
 
   Ruby/GSL is free software: you can redistribute it and/or modify it
   under the terms of the GNU General Public License.
@@ -1230,10 +1230,93 @@ static VALUE rb_gsl_matrix_complex_arccoth(VALUE obj)
   return rb_gsl_matrix_complex_XXX_complex(obj, gsl_complex_arccoth);
 }
 
+static VALUE rb_gsl_matrix_complex_indgen_bang(int argc, VALUE *argv[], VALUE obj)
+{
+  gsl_matrix_complex *v = NULL;
+  size_t start = 0, step = 1;
+  size_t i, j;
+  switch (argc) {
+  case 0:
+    break;
+  case 1:
+    start = FIX2INT(argv[0]);
+    break;
+  case 2:
+    start = FIX2INT(argv[0]);
+    step = FIX2INT(argv[1]);
+    break;
+  default:
+    rb_raise(rb_eArgError, "Wrong number of arguments (%d for 0-2)");
+  }
+  Data_Get_Struct(obj, gsl_matrix_complex, v);
+  for (i = 0, j = start; i < v->block->size; i++, j += step) {
+    v->data[2*i] = (double) j;
+  }
+  return obj;
+}
+
+static VALUE rb_gsl_matrix_complex_indgen(int argc, VALUE *argv, VALUE obj)
+{
+  gsl_matrix_complex *v = NULL, *vnew;
+  size_t start = 0, step = 1;
+  size_t i, j;
+  switch (argc) {
+  case 0:
+    break;
+  case 1:
+    start = FIX2INT(argv[0]);
+    break;
+  case 2:
+    start = FIX2INT(argv[0]);
+    step = FIX2INT(argv[1]);
+    break;
+  default:
+    rb_raise(rb_eArgError, "Wrong number of arguments (%d for 0-2)");
+  }
+  Data_Get_Struct(obj, gsl_matrix_complex, v);
+  vnew = gsl_matrix_complex_calloc(v->size1, v->size2);
+  for (i = 0, j = start; i < vnew->block->size; i++, j += step) {
+    vnew->data[2*i] = (double) j;
+  }
+  return Data_Wrap_Struct(cgsl_matrix_complex, 0, gsl_matrix_complex_free, vnew);
+}
+
+static VALUE rb_gsl_matrix_complex_indgen_singleton(int argc, VALUE *argv, VALUE obj)
+{
+  gsl_matrix_complex *vnew;
+  size_t n1, n2, start = 0, step = 1;
+  size_t i, j;
+  switch (argc) {
+  case 2:
+    n1 = (size_t) FIX2INT(argv[0]);
+    n2 = (size_t) FIX2INT(argv[1]);
+    break;
+  case 3:
+    n1 = (size_t) FIX2INT(argv[0]);
+    n2 = (size_t) FIX2INT(argv[1]);
+    start = FIX2INT(argv[2]);
+    break;
+  case 4:
+    n1 = (size_t) FIX2INT(argv[0]);
+    n2 = (size_t) FIX2INT(argv[1]);
+    start = FIX2INT(argv[2]);
+    step = FIX2INT(argv[3]);
+    break;
+  default:
+    rb_raise(rb_eArgError, "Wrong number of arguments (%d for 0-4)");
+  }
+  vnew = gsl_matrix_complex_calloc(n1, n2);
+  for (i = 0, j = start; i < vnew->block->size; i++, j += step) {
+    vnew->data[2*i] = (double) j;
+  }
+  return Data_Wrap_Struct(cgsl_matrix_complex, 0, gsl_matrix_complex_free, vnew);
+}
+
 void Init_gsl_matrix_complex(VALUE module)
 {
-  rb_define_singleton_method(cgsl_matrix_complex, "new", rb_gsl_matrix_complex_new, 2);
+  //  rb_define_singleton_method(cgsl_matrix_complex, "new", rb_gsl_matrix_complex_new, 2);
   rb_define_singleton_method(cgsl_matrix_complex, "alloc", rb_gsl_matrix_complex_new, 2);
+  rb_define_singleton_method(cgsl_matrix_complex, "[]", rb_gsl_matrix_complex_new, 2);
   rb_define_singleton_method(cgsl_matrix_complex, "calloc", rb_gsl_matrix_complex_new, 2);
   rb_define_singleton_method(cgsl_matrix_complex, "eye", rb_gsl_matrix_complex_eye, -1);
   rb_define_singleton_method(cgsl_matrix_complex, "diagonal", rb_gsl_matrix_complex_eye, -1);
@@ -1366,4 +1449,8 @@ void Init_gsl_matrix_complex(VALUE module)
   rb_define_method(cgsl_matrix_complex, "arcsech", rb_gsl_matrix_complex_arcsech, 0);
   rb_define_method(cgsl_matrix_complex, "arccsch", rb_gsl_matrix_complex_arccsch, 0);
   rb_define_method(cgsl_matrix_complex, "arccoth", rb_gsl_matrix_complex_arccoth, 0);
+
+  rb_define_method(cgsl_matrix_complex, "indgen", rb_gsl_matrix_complex_indgen, -1);
+  rb_define_method(cgsl_matrix_complex, "indgen!", rb_gsl_matrix_complex_indgen_bang, -1);
+  rb_define_singleton_method(cgsl_matrix_complex, "indgen", rb_gsl_matrix_complex_indgen_singleton, -1);
 }
