@@ -560,6 +560,8 @@ static VALUE rb_gsl_multifit_function_fdf_set_procs(int argc, VALUE *argv, VALUE
   rb_ary_store(ary, 0, argv[0]);
   rb_ary_store(ary, 1, argv[1]);
   switch (argc) {
+	case 2:
+		break;
   case 3:
     if (TYPE(argv[2]) == T_FIXNUM) {
       func->p = FIX2INT(argv[2]);
