@@ -1,7 +1,7 @@
 /*
   poly_source.c
   Ruby/GSL: Ruby extension library for GSL (GNU Scientific Library)
-    (C) Copyright 2001-2004 by Yoshiki Tsunesada
+    (C) Copyright 2001-2006 by Yoshiki Tsunesada
 
   Ruby/GSL is free software: you can redistribute it and/or modify it
   under the terms of the GNU General Public License.
@@ -390,6 +390,98 @@ static VALUE FUNCTION(rb_gsl_poly,complex_solve_cubic)(int argc, VALUE *argv, VA
   return Data_Wrap_Struct(cgsl_vector_complex, 0, gsl_vector_complex_free, r);
 }
 
+#ifdef HAVE_POLY_SOLVE_QUARTIC
+static VALUE FUNCTION(rb_gsl_poly,solve_quartic)(int argc, VALUE *argv, VALUE obj)
+{
+  double x0, x1, x2, x3;
+  GSL_TYPE(gsl_vector) *v = NULL;
+  gsl_vector *r = NULL;
+  int n;
+  switch (argc) {
+  case 4:
+    n = gsl_poly_solve_quartic(NUMCONV2(argv[0]), NUMCONV2(argv[1]), NUMCONV2(argv[2]),
+			       NUMCONV2(argv[3]),
+			       &x0, &x1, &x2, &x3);
+    break;
+  case 1:
+    switch (TYPE(argv[0])) {
+    case T_ARRAY:
+      n = gsl_poly_solve_quartic(NUMCONV2(rb_ary_entry(argv[0], 0)), 
+			       NUMCONV2(rb_ary_entry(argv[0], 1)),
+			       NUMCONV2(rb_ary_entry(argv[0], 2)),
+			       NUMCONV2(rb_ary_entry(argv[0], 3)),
+			       &x0, &x1, &x2, &x3);
+      break;
+    default:
+      CHECK_VEC(argv[0]);
+      Data_Get_Struct(argv[0], GSL_TYPE(gsl_vector), v);
+      n = gsl_poly_solve_quartic(FUNCTION(gsl_vector,get)(v, 0),
+			       FUNCTION(gsl_vector,get)(v, 1),
+			       FUNCTION(gsl_vector,get)(v, 2),
+			       FUNCTION(gsl_vector,get)(v, 3),
+			       &x0, &x1, &x2, &x3);
+      break;
+    }
+    break;
+  default:
+    rb_raise(rb_eArgError, 
+	     "wrong number of arguments (3 numbers or 1 array or 1 vector)");
+    break;
+  }
+  r = gsl_vector_alloc(4);
+  gsl_vector_set(r, 0, x0);
+  gsl_vector_set(r, 1, x1);
+  gsl_vector_set(r, 2, x2);
+  gsl_vector_set(r, 3, x3);
+  return Data_Wrap_Struct(cgsl_vector, 0, gsl_vector_free, r);
+}
+
+static VALUE FUNCTION(rb_gsl_poly,complex_solve_quartic)(int argc, VALUE *argv, VALUE obj)
+{
+  gsl_complex z0, z1, z2, z3;
+  GSL_TYPE(gsl_vector) *v = NULL;
+  gsl_vector_complex *r = NULL;
+  int n;
+  switch (argc) {
+  case 4:
+    n = gsl_poly_complex_solve_quartic(NUMCONV2(argv[0]), NUMCONV2(argv[1]), 
+				       NUMCONV2(argv[2]), NUMCONV2(argv[3]),
+				       &z0, &z1, &z2, &z3);
+    break;
+  case 1:
+    switch (TYPE(argv[0])) {
+    case T_ARRAY:
+      n = gsl_poly_complex_solve_quartic(NUMCONV2(rb_ary_entry(argv[0], 0)), 
+					 NUMCONV2(rb_ary_entry(argv[0], 1)),
+					 NUMCONV2(rb_ary_entry(argv[0], 2)),
+					 NUMCONV2(rb_ary_entry(argv[0], 3)),
+					 &z0, &z1, &z2, &z3);
+      break;
+    default:
+      CHECK_VEC(argv[0]);
+      Data_Get_Struct(argv[0], GSL_TYPE(gsl_vector), v);
+      n = gsl_poly_complex_solve_quartic(FUNCTION(gsl_vector,get)(v, 0),
+					 FUNCTION(gsl_vector,get)(v, 1),
+					 FUNCTION(gsl_vector,get)(v, 2),
+					 FUNCTION(gsl_vector,get)(v, 3),
+					 &z0, &z1, &z2, &z3);
+      break;
+    }
+    break;
+  default:
+    rb_raise(rb_eArgError, 
+	     "wrong number of arguments (3 numbers or 1 array or 1 vector)");
+    break;
+  }
+  r = gsl_vector_complex_alloc(4);
+  gsl_vector_complex_set(r, 0, z0);
+  gsl_vector_complex_set(r, 1, z1);
+  gsl_vector_complex_set(r, 2, z2);
+  gsl_vector_complex_set(r, 3, z3);
+  return Data_Wrap_Struct(cgsl_vector_complex, 0, gsl_vector_complex_free, r);
+}
+
+#endif
 /* singleton method */
 VALUE FUNCTION(rb_gsl_poly,complex_solve)(int argc, VALUE *argv, VALUE obj)
 {
@@ -572,6 +664,62 @@ static VALUE FUNCTION(rb_gsl_poly,complex_solve_cubic2)(VALUE obj)
   return Data_Wrap_Struct(cgsl_vector_complex, 0, gsl_vector_complex_free, r);
 }
 
+#ifdef HAVE_POLY_SOLVE_QUARTIC
+/* a4 x**4 + a3 x**3 + a2 x**2 + a1 x + a0 = 0 */
+static VALUE FUNCTION(rb_gsl_poly,solve_quartic2)(VALUE obj)
+{
+  GSL_TYPE(gsl_vector) *v = NULL;
+  gsl_vector *r = NULL;
+  double a4, a3, a2, a1, a0;
+  double x0, x1, x2, x3;
+  int n;
+
+  Data_Get_Struct(obj, GSL_TYPE(gsl_vector), v);
+  if (v->size < 5) {
+    rb_raise(rb_eArgError, "the order of the object is less than 4.");
+  }
+  a4 = FUNCTION(gsl_vector,get)(v, 4);   
+  a3 = FUNCTION(gsl_vector,get)(v, 3)/a4;   
+  a2 = FUNCTION(gsl_vector,get)(v, 2)/a4;   /* coefficients */
+  a1 = FUNCTION(gsl_vector,get)(v, 1)/a4;
+  a0 = FUNCTION(gsl_vector,get)(v, 0)/a4;
+  n = gsl_poly_solve_quartic(a3, a2, a1, a0, &x0, &x1, &x2, &x3);
+  r = gsl_vector_alloc(3);
+  r = gsl_vector_alloc(4);
+  gsl_vector_set(r, 0, x0);
+  gsl_vector_set(r, 1, x1);
+  gsl_vector_set(r, 2, x2);
+  gsl_vector_set(r, 3, x3);
+  return Data_Wrap_Struct(cgsl_vector, 0, gsl_vector_free, r);
+}
+
+static VALUE FUNCTION(rb_gsl_poly,complex_solve_quartic2)(VALUE obj)
+{
+  GSL_TYPE(gsl_vector) *v = NULL;
+  gsl_vector_complex *r = NULL;
+  double a4, a3, a2, a1, a0;
+  int n;
+  gsl_complex z0, z1, z2, z3;
+  Data_Get_Struct(obj, GSL_TYPE(gsl_vector), v);
+  if (v->size < 5) {
+    rb_raise(rb_eArgError, "the order of the object is less than 4.");
+  }
+  a4 = FUNCTION(gsl_vector,get)(v, 4);   
+  a3 = FUNCTION(gsl_vector,get)(v, 3)/a4;   
+  a2 = FUNCTION(gsl_vector,get)(v, 2)/a4;   /* coefficients */
+  a1 = FUNCTION(gsl_vector,get)(v, 1)/a4;
+  a0 = FUNCTION(gsl_vector,get)(v, 0)/a4;
+  n = gsl_poly_complex_solve_quartic(a3, a2, a1, a0, &z0, &z1, &z2, &z3);
+  r = gsl_vector_complex_alloc(4);
+  gsl_vector_complex_set(r, 0, z0);
+  gsl_vector_complex_set(r, 1, z1);
+  gsl_vector_complex_set(r, 2, z2);
+  gsl_vector_complex_set(r, 3, z3);
+  return Data_Wrap_Struct(cgsl_vector_complex, 0, gsl_vector_complex_free, r);
+}
+
+#endif
+
 /* method */
 VALUE FUNCTION(rb_gsl_poly,complex_solve2)(int argc, VALUE *argv, VALUE obj)
 {
@@ -1287,6 +1435,11 @@ void FUNCTION(Init_gsl_poly,init)(VALUE module)
 			     FUNCTION(rb_gsl_poly,complex_solve_quadratic), -1);
   rb_define_singleton_method(mgsl_poly_complex, "solve_cubic",
 			     FUNCTION(rb_gsl_poly,complex_solve_cubic), -1);
+#ifdef HAVE_POLY_SOLVE_QUARTIC
+  rb_define_singleton_method(mgsl_poly_complex, "solve_quartic",
+			     FUNCTION(rb_gsl_poly,complex_solve_quartic), -1);
+#endif
+
   rb_define_singleton_method(mgsl_poly_complex, "solve",
 			     FUNCTION(rb_gsl_poly,complex_solve), -1);
   rb_define_singleton_method(mgsl_poly_complex, "roots", 
@@ -1297,10 +1450,18 @@ void FUNCTION(Init_gsl_poly,init)(VALUE module)
 			     FUNCTION(rb_gsl_poly,solve_quadratic), -1);
   rb_define_singleton_method(GSL_TYPE(cgsl_poly), "solve_cubic", 
 			     FUNCTION(rb_gsl_poly,solve_cubic), -1);
+
   rb_define_singleton_method(GSL_TYPE(cgsl_poly), "complex_solve_quadratic", 
 			     FUNCTION(rb_gsl_poly,complex_solve_quadratic), -1);
   rb_define_singleton_method(GSL_TYPE(cgsl_poly), "complex_solve_cubic", 
 			     FUNCTION(rb_gsl_poly,complex_solve_cubic), -1);
+#ifdef HAVE_POLY_SOLVE_QUARTIC
+  rb_define_singleton_method(GSL_TYPE(cgsl_poly), "solve_quartic",
+			     FUNCTION(rb_gsl_poly,solve_quartic), -1);
+
+  rb_define_singleton_method(GSL_TYPE(cgsl_poly), "complex_solve_quartic",
+			     FUNCTION(rb_gsl_poly,complex_solve_quartic), -1);
+#endif
   rb_define_singleton_method(GSL_TYPE(cgsl_poly), "complex_solve",
 			     FUNCTION(rb_gsl_poly,complex_solve), -1);
 
@@ -1326,6 +1487,13 @@ void FUNCTION(Init_gsl_poly,init)(VALUE module)
   rb_define_method(GSL_TYPE(cgsl_poly), "complex_solve_cubic", 
 		   FUNCTION(rb_gsl_poly,complex_solve_cubic2), 0);
 
+#ifdef HAVE_POLY_SOLVE_QUARTIC
+  rb_define_method(GSL_TYPE(cgsl_poly), "solve_quartic", 
+		   FUNCTION(rb_gsl_poly,solve_quartic2), 0);
+  rb_define_method(GSL_TYPE(cgsl_poly), "complex_solve_quartic", 
+		   FUNCTION(rb_gsl_poly,complex_solve_quartic2), 0);
+#endif
+
   rb_define_method(GSL_TYPE(cgsl_poly), "complex_solve", 
 		   FUNCTION(rb_gsl_poly,complex_solve2), -1);
   rb_define_alias(GSL_TYPE(cgsl_poly), "solve", "complex_solve");
