@@ -442,6 +442,18 @@ static VALUE rb_gsl_stats_covariance_m2(VALUE obj, VALUE vv1, VALUE vv2,
 					   stride2, size, NUM2DBL(m1), NUM2DBL(m2)));
 }
 
+#ifdef HAVE_GSL_STATS_CORRELATION
+static VALUE rb_gsl_stats_correlation(VALUE obj, VALUE vv1, VALUE vv2)
+{
+  double *data1, *data2;
+  size_t stride1, stride2, size;
+  data1 = get_vector_ptr(vv1, &stride1, &size);
+  data2 = get_vector_ptr(vv2, &stride2, &size);
+  return rb_float_new(gsl_stats_correlation(data1, stride1, data2,
+					   stride2, size));
+}
+#endif
+
 static VALUE rb_gsl_stats_wmean2(VALUE obj, VALUE ww, VALUE dd)
 {
   double wmean, *dataw = NULL, *data = NULL;
@@ -661,6 +673,11 @@ void Init_gsl_stats(VALUE module)
 
   rb_define_singleton_method(mgsl_stats, "covariance", rb_gsl_stats_covariance2, 2);
   rb_define_singleton_method(mgsl_stats, "covariance_m", rb_gsl_stats_covariance_m2, 4);
+  
+#ifdef HAVE_GSL_STATS_CORRELATION
+  rb_define_singleton_method(mgsl_stats, "correlation", rb_gsl_stats_correlation, 2);  
+#endif
+
   /*****/
   
   rb_define_singleton_method(mgsl_stats, "wmean", rb_gsl_stats_wmean2, -1);
