@@ -541,11 +541,11 @@ static VALUE rb_gsl_vector_graph2(int argc, VALUE *argv, VALUE obj)
       draw_narray(argv[0], fp);
 #endif
     } else {
-      if (fp) fclose(fp);
+      if (fp) pclose(fp);
       rb_raise(rb_eTypeError, "wrong argument type %s", 
 	       rb_class2name(CLASS_OF(argv[0])));
     }
-    if (fp) fclose(fp);
+    if (fp) pclose(fp);
     return Qtrue;
   } else {
     fp = popen(command, "w");
@@ -593,7 +593,7 @@ static VALUE rb_gsl_vector_graph2(int argc, VALUE *argv, VALUE obj)
       for (j = 0; j < n; j++) gsl_vector_set(x, j, (double) j);
       flag = 1;
     } else {
-      if (fp) fclose(fp);
+      if (fp) pclose(fp);
       rb_raise(rb_eTypeError, "wrong argument type %s", 
 	       rb_class2name(CLASS_OF(argv[0])));
     }
@@ -834,7 +834,7 @@ static VALUE rb_gsl_vector_plot2(int argc, VALUE *argv, VALUE obj)
   }
   fprintf(fp, "e\n");
   fflush(fp);
-  fclose(fp);
+  pclose(fp);
   fp = NULL;
   return Qtrue;
 }
@@ -910,7 +910,7 @@ static VALUE rb_gsl_vector_filescan_na(VALUE klass, VALUE file)
   sprintf(buf, "wc %s", filename);
   fp = popen(buf, "r");
   fgets(buf, 1024, fp);
-  fclose(fp);
+  pclose(fp);
   sscanf(buf, "%d", &nn);
   lines = (size_t) nn;      /* vector length */
   shape[0] = lines;
