@@ -40,8 +40,14 @@
 #ifndef HAVE_EIGEN_FRANCIS
 #define HAVE_EIGEN_FRANCIS
 #endif
+#ifndef HAVE_EIGEN_GEN
+#define HAVE_EIGEN_GEN
+#endif
+#ifndef HAVE_GSL_STATS_CORRELATION
+#define HAVE_GSL_STATS_CORRELATION
+#endif
 #ifndef RUBY_GSL_VERSION
-#define RUBY_GSL_VERSION "1.9.0"
+#define RUBY_GSL_VERSION "1.9.1"
 #endif
 #ifndef RUBY_1_8_LATER
 #define RUBY_1_8_LATER
