@@ -11,7 +11,7 @@ DF = GSL::Function.alloc { |x|
 }
 # Find zero-point of the derivative in interval (0.01, 5)
 peak, = DF.fsolve(0.01, 5)
-printf("Peak is found at %3.2f.\n", peak)
+printf("A peak is found at %3.2f.\n", peak)
 
 x = GSL::Vector.linspace(0, 5, 100)
 s = GSL::Sf::synchrotron_1(x)
