@@ -9,4 +9,4 @@ r = 4*a*cost3
 x = r*GSL::Sf::cos(t)
 y = r*GSL::Sf::sin(t)
 
-graph(x, y, "-T X -C")
+GSL::graph(x, y, "-T X -C")
