@@ -1,8 +1,8 @@
 #!/usr/bin/env ruby
-require("gsl")
+require("rbgsl")
 
 N = 10000
-rng = Rng.alloc
+rng = GSL::Rng.alloc
 data = rng.exponential(2, N)
 h = GSL::Histogram.alloc(100, [0, 15])
 h.fill(data)
@@ -13,7 +13,7 @@ a = result[0]
 b = result[1]
 
 x = GSL::Vector.linspace(0, 15, 100)
-y = a*Sf::exp(x*b)
-graph(h, [x, y], "-C -g 3")
+y = a*GSL::Sf::exp(x*b)
+GSL::graph(h, [x, y], "-C -g 3")
 
   
