@@ -1,7 +1,7 @@
 #!/usr/bin/env ruby
 # This is equivalent to the gsl-histogram program
 
-require("gsl")
+require("rbgsl")
 require("getopts")
 
 getopts(nil, "DISPLAY_STATS")
@@ -22,7 +22,7 @@ else
   exit
 end
 
-h = GSL::GSL::Histogram.alloc(n)
+h = GSL::Histogram.alloc(n)
 h.set_ranges_uniform(a, b)
 
 while line = STDIN.gets
