@@ -1,7 +1,7 @@
 #!/usr/bin/env ruby
-require("gsl")
+require("rbgsl")
 
-h = GSL::GSL::Histogram.alloc(5)
+h = GSL::Histogram.alloc(5)
 p h
 p h.size
 
