@@ -1,11 +1,11 @@
 #!/usr/bin/env ruby
-require("gsl"); include Min
-fn1 = Function.alloc { |x| Math::cos(x) + 1.0 }
+require("rbgsl")
+fn1 = GSL::Function.alloc { |x| Math::cos(x) + 1.0 }
 iter = 0;  max_iter = 500
 m = 2.0             # initial guess
 m_expected = Math::PI
 a = 0.0; b = 6.0
-gmf = FMinimizer.alloc(FMinimizer::BRENT)
+gmf = GSL::Min::FMinimizer.alloc(GSL::Min::FMinimizer::BRENT)
 gmf.set(fn1, m, a, b)
 printf("Using %s method\n", gmf.name)
 printf("%5s [%9s, %9s] %9s %10s %9s\n", "iter", "lower", "upper", "min",
@@ -23,7 +23,7 @@ begin
          iter, a, b, m, m - m_expected, b - a);
 end while status == GSL::CONTINUE and iter < max_iter
 
-x = Vector.linspace(0, 6, 50)
+x = GSL::Vector.linspace(0, 6, 50)
 mx = gmf.x_minimum
 min = fn1.eval(mx)
-GSL::graph([x, fn1.eval(x)], [Vector[mx], Vector[min]], "-C -g 3 -S 4 -m -1")
+GSL::graph([x, fn1.eval(x)], [GSL::Vector[mx], GSL::Vector[min]], "-C -g 3 -S 4 -m -1")
