@@ -1,5 +1,6 @@
 #!/usr/bin/env ruby
-require("gsl")
+require("rbgsl")
+include GSL
 include GSL::Siman
 
 N_TRIES = 200
